%Author: Bassel Tarbush
%Date: 24 March 2017
%MATLAB version used: R2017a

%This scripts consists of multiple script sections, which can be run
%independently. Each section generates a particular figure in the paper.


%%
%This script section genertes Figure 2.

%sets a seed for the random number generator.
rng(0,'twister')
%n is the number of firms
n=1000;


%Xs is a vector of values randomly drawn from a uniform on [0,1] and
%sorted in ascending order.
a=1; b=1;
Xs=sort([0,betarnd(a,b,1,n-1),1]);
share=zeros(1,n);
for i=2:(n-1)
    share(i)=betacdf( (Xs(i+1) + Xs(i))/2 ,a,b) -...
        betacdf( (Xs(i) + Xs(i-1))/2 ,a,b);
end
%shareA is the vector of resulting market shares (as defined in equation (1)).

%The Xs below is now a vector of values randomly drawn from a  Beta(7,5)
%and sorted in ascending order.
a=7; b=5;
Xs=sort([0,betarnd(a,b,1,n-1),1]);
shareB=zeros(1,n);
for i=2:(n-1)
    shareB(i)=betacdf( (Xs(i+1) + Xs(i))/2 ,a,b) -...
        betacdf( (Xs(i) + Xs(i-1))/2 ,a,b);
end
%shareB is the vector of resulting market shares (as defined in equation (1)).


%The rest of the script section simply generates Figure 2.
h=figure('position',[200 200 600 600]);
set(h,'defaulttextinterpreter','latex');

wgap=0.05;
hgap=(3/4).*wgap;
width=0.5 - 1.5*wgap;
height=0.5 - 2*hgap;
pos1=[wgap,0.5+hgap,width,height];
pos2=[0.5 + wgap/2,0.5 + hgap,width,height];
pos3=[wgap,hgap,width,height];
pos4=[0.5 + wgap/2,hgap,width,height];
str='fill';
res=0.1;
textSize=16;


s1=subplot(2,2,1);
plot(0:(0.1*res):1,betapdf(0:(0.1*res):1,1,1),'LineWidth',1.5,'color','k')
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick= [0,1] ;
ax.XTickLabel={'$0$','$1$'};
ax.YTick= [] ;
set(gca,'Position',pos1)
xlim([0,1])
axis(str)
TitleH = title('($a_1$) U($0,1$) distribution of consumers');

s2=subplot(2,2,2);
histogram(n*share,0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, 4.*(0:res:n).*exppdf(2.*(0:res:n),1).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos2)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=1000$','Gamma($2,2$)'},'Location','northeast','Interpreter','latex');
TitleH = title('($a_2$) Resulting market share distribution');


s3=subplot(2,2,3);
plot(0:(0.1*res):1,betapdf(0:(0.1*res):1,a,b),'LineWidth',1.5,'color','k')
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick= [0 1] ;
ax.XTickLabel={'$0$','$1$'};
ax.YTick= [] ;
set(gca,'Position',pos3)
xlim([0,1])
axis(str)
TitleH = title('($b_1$) Beta($7,5$) distribution of consumers');


s4=subplot(2,2,4);
histogram(n*shareB,0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, 4.*(0:res:n).*exppdf(2.*(0:res:n),1).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos4)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=1000$','Gamma($2,2$)'},'Location','northeast','Interpreter','latex');
TitleH = title('($b_2$) Resulting market share distribution');


set(findall(h,'-property','FontSize'),'FontSize',textSize)








%%

%This script section generates Figure 6.

%sets a seed for the random number generator.
rng(1,'twister')
%N is the set of number of firms
N=[50,100,250,1000];


%Xs is a vector of values randomly drawn from a uniform on [0,1] and
%sorted in ascending order. And the loop below generates the shares
%for different values of n in N.
a=1; b=1;
share={};
for j=1:4
    n=N(j);
    Xs=sort([0,betarnd(a,b,1,n-1),1]);
    for i=2:(n-1)
        share{j}(i)=betacdf( (Xs(i+1) + Xs(i))/2 ,a,b) -...
            betacdf( (Xs(i) + Xs(i-1))/2 ,a,b);
    end
end
%share is the vector of resulting market shares (as defined in equation (1)).


%The rest of the script section simply generates Figure 6.
h=figure('position',[200 200 600 600]);
set(h,'defaulttextinterpreter','latex');

wgap=0.05;
hgap=(3/4).*wgap;
width=0.5 - 1.5*wgap;
height=0.5 - 2*hgap;
pos1=[wgap,0.5+hgap,width,height];
pos2=[0.5 + wgap/2,0.5 + hgap,width,height];
pos3=[wgap,hgap,width,height];
pos4=[0.5 + wgap/2,hgap,width,height];
str='fill';
res=0.1;
textSize=16;


s1=subplot(2,2,1);
n=N(1);
histogram(n*share{1},0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, 4.*(0:res:n).*exppdf(2.*(0:res:n),1).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos1)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=50$','Gamma($2,2$)'},'Location','northeast','Interpreter','latex');
%TitleH = title('($a$)');

s2=subplot(2,2,2);
n=N(2);
histogram(n*share{2},0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, 4.*(0:res:n).*exppdf(2.*(0:res:n),1).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos2)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=100$','Gamma($2,2$)'},'Location','northeast','Interpreter','latex');
%TitleH = title('($b$)');

s3=subplot(2,2,3);
n=N(3);
histogram(n*share{3},0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, 4.*(0:res:n).*exppdf(2.*(0:res:n),1).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos3)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=250$','Gamma($2,2$)'},'Location','northeast','Interpreter','latex');
%TitleH = title('($c$)');


s4=subplot(2,2,4);
n=N(4);
histogram(n*share{4},0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, 4.*(0:res:n).*exppdf(2.*(0:res:n),1).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos4)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=1000$','Gamma($2,2$)'},'Location','northeast','Interpreter','latex');
%TitleH = title('($d$)');

set(findall(h,'-property','FontSize'),'FontSize',textSize)










%%

%This script section generates Figure 7.

%In this next part I generate spacings of order one with a valuefunction V
%to match the comments made in Remark 1..
rng(0,'twister')
%n is the number of firms
n=1000;


%The following generates spacings of order one with a value function V.
%V(x) = x.^2 below.
a=1; b=1;
Xs=sort([0,betarnd(a,b,1,n-1),1]);
shareA=zeros(1,n);
syms V(x)
V(x) = x^2;
dV=matlabFunction(diff(V));
invV=finverse(V);
dinvV=matlabFunction(diff(invV));
invV=matlabFunction(invV);
for i=1:(n-1)
    shareA(i)=V( Xs(i+1) ) - V( Xs(i) );
end
f=@(x) betapdf(x,a,b)./dV(x);
fun=@(x,c) exp(-c.*f(x)).*f(x).*betapdf(x,a,b);
H =@(c) integral(@(x) fun(x,c),-Inf,Inf);

%Hnum is the empirical distribution of the spacings.
res=0.1;
D=0:res:n;
Hnum=zeros(1,length(D));
for i=1:length(D)
    Hnum(i)=H(D(i));
end


%In this next part I generate sapcings of order four, to match the comments
%made in Remark 4.

%sets a seed for the random number generator.
rng(1,'twister')
%n is the number of firms
n=1000;


%Xs is a vector of values randomly drawn from a uniform on [0,1] and
%sorted in ascending order.
a=1; b=1;
share=zeros(1,n);
Xs=sort([0,betarnd(a,b,1,n-1),1]);
for i=3:(n-2)
    share(i)=betacdf( (Xs(i+2) + Xs(i))/2 ,a,b) -...
        betacdf( (Xs(i) + Xs(i-2))/2 ,a,b);
end


%The rest of the script section simply generates Figure 7.
h=figure('position',[300 300 800 400]);
set(h,'defaulttextinterpreter','latex');

wgap=0.05;
hgap=wgap;
width=0.5 - 1.5*wgap;
height=1 - 2*hgap;
pos1=[wgap,hgap,width,height];
pos2=[0.5 + wgap/2, hgap,width,height];
str='fill';
res=0.1;
textSize=16;


s1=subplot(1,2,1);
histogram(n*shareA,D,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(D, Hnum.*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos1)
xlim([0 10])
ylim([0 0.2])
axis(str)
lgd=legend({'Simulated $n=1000$','Analytic'},'Location','northeast','Interpreter','latex');
TitleH = title('($a$)');


s2=subplot(1,2,2);
histogram(n*share,0:res:n,'Normalization','probability','FaceAlpha',0.15,'FaceColor','k')
hold on
plot(0:res:n, gampdf(0:res:n,4,0.5).*res,'LineWidth',1.5,'color','k' )
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 10];
ax.XTickLabel={'$0$','$10$'};
ax.YTick=[ ];
set(gca,'Position',pos2)
xlim([0 10])
ylim([0 0.075])
axis(str)
lgd=legend({'Simulated $n=1000$','Gamma($4,2$)'},'Location','northeast','Interpreter','latex');
TitleH = title('($b$)');

set(findall(h,'-property','FontSize'),'FontSize',textSize)











%%

%This script section generates Figure 5.

%The first part of this script section compares the analytical \pi_i(x) 
%with the simulated average payoff at each location x. (These results are
%not shown in the paper).

%The second part of this script section compares the analytical 
%\tilde{\pi}_i(x) with the simulated average payoff at each location x.

%PAYOFFS, classic pure location game
n=20;
X=0:0.01:1;
tries=10000;
V1=0.5.*( (1-X).*(X.^(n-1)) + X.*((1-X).^(n-1)) + 2./n ...
    - ((1-X).^n)./n - (X.^n)./n );
U=rand(tries,n-1);
pi1=zeros(tries,length(X));
for i=1:length(X)
    for j=1:tries
        A=sort(U(j,:));
        K=A - X(i);
        c=sum(K >0);
        idxR = find(K>0,1,'first'); %idx of closest to right.
        if isempty(idxR)==1
            pi1(j,i) = 1 - (A(n-1)+X(i))./2;
        end
        if isempty(idxR)==0 && idxR==1
            pi1(j,i) = (A(1)+X(i))./2;
        end
        if isempty(idxR)==0 && idxR>1
            pi1(j,i) = (A(idxR) - A(idxR-1))./2;
        end
    end
end
M1=mean(pi1,1);
plot(X,M1,'k',X,V1,'r')

%PAYOFFS, variant with overlapping markets
rng(1,'twister')
n=10;
X=0:0.01:1;
tries=10000;
U=rand(tries,n-1);
V2= 2./n - ((1-X).^n)./n - (X.^n)./n + 0.5.*(n-1).*(...
    ((1-X).^2).*(X.^(n-2)) + (X.^2).*((1-X).^(n-2)) );
pi2=zeros(tries,length(X));
for i=1:length(X)
    for j=1:tries
        A=sort(U(j,:));
        K=A - X(i);
        c=sum(K >0);
        idxR = find(K>0,1,'first'); %idx of closest to right.
        if isempty(idxR)==0 && idxR==1
            pi2(j,i) = (A(2)+X(i))./2;
        end
        if isempty(idxR)==0 && idxR==2
            pi2(j,i) = (A(3)+X(i))./2;
        end
        if isempty(idxR)==0 && idxR>2 && idxR<n-1
            pi2(j,i) = (A(idxR+1) - A(idxR-2))./2;
        end
        if isempty(idxR)==0 && idxR==n-1
            pi2(j,i) = 1 - ( A(n-3) + X(i))./2;
        end
        if isempty(idxR)==1
            pi2(j,i) = 1 - (A(n-2)+X(i))./2;
        end
        
        
    end
end
M2=mean(pi2,1);

h=figure('position',[300 300 300 300]);
set(h,'defaulttextinterpreter','latex');
str='fill';
textSize=16;
plot(X,M2,'k.',X,V2,'k-') 
ax = gca;
set(gca,'TickLabelInterpreter', 'latex')
ax.XTick=[0 1];
ax.XTickLabel={'$0$','$1$'};
ax.YTick=[ ];
xlim([0 1])
axis(str)
lgd=legend({'Simulated (average over $10000$ rounds)','Analytic $\tilde{\pi}_i(x)$'},'Location','south','Interpreter','latex');

